@@ -1,7 +1,7 @@
 from dnsimple.struct.struct import Struct
 from dnsimple.struct.access_token import AccessToken
 from dnsimple.struct.account import Account
-from dnsimple.struct.certificate import Certificate, CertificateBundle, LetsencryptCertificateInput, CertificatePurchase, CertificateRenewal
+from dnsimple.struct.certificate import Certificate, CertificateBundle, LetsencryptCertificateInput, LetsencryptCertificateRenewalInput, CertificatePurchase, CertificateRenewal
 from dnsimple.struct.collaborator import Collaborator
 from dnsimple.struct.contact import Contact
 from dnsimple.struct.dnssec import Dnssec
